@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '3.92';
+$CPAN::Perl::Releases::VERSION = '5.20200220';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -234,6 +234,24 @@ our $data =
 "5.29.7" => { id => 'ABIGAIL' },
 "5.29.8" => { id => 'ATOOMIC' },
 "5.29.9" => { id => 'ZAKAME' },
+"5.28.2-RC1" => { id => 'SHAY' },
+"5.28.2" => { id => 'SHAY' },
+"5.29.10" => { id => 'XSAWYERX' },
+"5.30.0-RC1" => { id => 'XSAWYERX' },
+"5.30.0-RC2" => { id => 'XSAWYERX' },
+"5.30.0" => { id => 'XSAWYERX' },
+"5.31.0" => { id => 'XSAWYERX' },
+"5.31.1" => { id => 'ETHER' },
+"5.31.2" => { id => 'SHAY' },
+"5.31.3" => { id => 'TOMHUKINS' },
+"5.31.4" => { id => 'CORION' },
+"5.31.5" => { id => 'SHAY' },
+"5.30.1-RC1" => { id => 'SHAY' },
+"5.30.1" => { id => 'SHAY' },
+"5.31.6" => { id => 'BINGOS' },
+"5.31.7" => { id => 'ATOOMIC' },
+"5.31.8" => { id => 'WOLFSAGE' },
+"5.31.9" => { id => 'RENEEB' },
 };
 
 sub perl_tarballs {
@@ -302,7 +320,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 3.92
+version 5.20200220
 
 =head1 SYNOPSIS
 
@@ -367,7 +385,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Chris Williams.
+This software is copyright (c) 2020 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
